==> aws-cdk-scala_2.12-0.5.1-sources.jar: io/burkard/cdk/cloudassembly/schema/MissingContext.scala <==
package io.burkard.cdk.cloudassembly.schema

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object MissingContext {

  def apply(
    provider: software.amazon.awscdk.cloudassembly.schema.ContextProvider,
    props0: software.amazon.awscdk.cloudassembly.schema.LoadBalancerContextQuery,
    props1: software.amazon.awscdk.cloudassembly.schema.LoadBalancerListenerContextQuery,
    props2: software.amazon.awscdk.cloudassembly.schema.EndpointServiceAvailabilityZonesContextQuery,
    props3: software.amazon.awscdk.cloudassembly.schema.SecurityGroupContextQuery,
    props4: software.amazon.awscdk.cloudassembly.schema.KeyContextQuery,
    props5: software.amazon.awscdk.cloudassembly.schema.AmiContextQuery,
    props6: software.amazon.awscdk.cloudassembly.schema.AvailabilityZonesContextQuery,
    props7: software.amazon.awscdk.cloudassembly.schema.HostedZoneContextQuery,
    props8: software.amazon.awscdk.cloudassembly.schema.SSMParameterContextQuery,
    props9: software.amazon.awscdk.cloudassembly.schema.VpcContextQuery,
    key: String
  ): software.amazon.awscdk.cloudassembly.schema.MissingContext =
    (new software.amazon.awscdk.cloudassembly.schema.MissingContext.Builder)
      .provider(provider)
      .props(props0)
      .props(props1)
      .props(props2)
      .props(props3)
      .props(props4)
      .props(props5)
      .props(props6)
      .props(props7)
      .props(props8)
      .props(props9)
      .key(key)
      .build()
}

==> aws-cdk-scala_2.12-0.13.0-sources.jar: io/burkard/cdk/cloudassembly/schema/MissingContext.scala <==
package io.burkard.cdk.cloudassembly.schema

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object MissingContext {

  def apply(
    provider: software.amazon.awscdk.cloudassembly.schema.ContextProvider,
    props0: software.amazon.awscdk.cloudassembly.schema.LoadBalancerContextQuery,
    props1: software.amazon.awscdk.cloudassembly.schema.LoadBalancerListenerContextQuery,
    props2: software.amazon.awscdk.cloudassembly.schema.EndpointServiceAvailabilityZonesContextQuery,
    props3: software.amazon.awscdk.cloudassembly.schema.SecurityGroupContextQuery,
    props4: software.amazon.awscdk.cloudassembly.schema.KeyContextQuery,
    props5: software.amazon.awscdk.cloudassembly.schema.PluginContextQuery,
    props6: software.amazon.awscdk.cloudassembly.schema.AmiContextQuery,
    props7: software.amazon.awscdk.cloudassembly.schema.AvailabilityZonesContextQuery,
    props8: software.amazon.awscdk.cloudassembly.schema.HostedZoneContextQuery,
    props9: software.amazon.awscdk.cloudassembly.schema.SSMParameterContextQuery,
    props10: software.amazon.awscdk.cloudassembly.schema.VpcContextQuery,
    key: String
  ): software.amazon.awscdk.cloudassembly.schema.MissingContext =
    (new software.amazon.awscdk.cloudassembly.schema.MissingContext.Builder)
      .provider(provider)
      .props(props0)
      .props(props1)
      .props(props2)
      .props(props3)
      .props(props4)
      .props(props5)
      .props(props6)
      .props(props7)
      .props(props8)
      .props(props9)
      .props(props10)
      .key(key)
      .build()
}
